@@ -21,6 +21,6 @@
 namespace FUSE
 {
   int
-  opendir(const char     *fusepath,
-          fuse_file_info *ffi);
+  opendir(const char       *fusepath,
+          fuse_file_info_t *ffi);
 }
