@@ -29,8 +29,8 @@
 namespace FUSE
 {
   int
-  readdir(fuse_file_info *ffi_,
-          fuse_dirents_t *buf_)
+  readdir(const fuse_file_info_t *ffi_,
+          fuse_dirents_t         *buf_)
   {
     DirInfo            *di     = reinterpret_cast<DirInfo*>(ffi_->fh);
     const fuse_context *fc     = fuse_get_context();
