@@ -21,14 +21,14 @@
 namespace FUSE
 {
   int
-  write(const char     *buf,
-        size_t          count,
-        off_t           offset,
-        fuse_file_info *ffi);
+  write(const fuse_file_info_t *ffi,
+        const char             *buf,
+        size_t                  count,
+        off_t                   offset);
 
   int
-  write_null(const char     *buf,
-             size_t          count,
-             off_t           offset,
-             fuse_file_info *ffi);
+  write_null(const fuse_file_info_t *ffi,
+             const char             *buf,
+             size_t                  count,
+             off_t                   offset);
 }
